# karp-lex-core

>![NOTE] rename to `karp-lex-types`

- **karp-lex-core** [![PyPI version](https://badge.fury.io/py/karp-lex-core.svg)](https://badge.fury.io/py/karp-lex-core)

The core for karp-lex

Contains commands, entry_dto and unique_id for `karp.lex` in `karp.backend`.
